@@ -57,7 +57,7 @@ public class DatasourceLoadConfig {
                 "JDBC-CLICKHOUSE",
                 "org.apache.seatunnel.datasource.plugin.clickhouse.jdbc.ClickhouseJdbcDataSourceFactory");
         classLoaderFactoryName.put(
-                "HIVE", "com.whaleops.datasource.datasource.plugin.hive.HiveDataSourceFactory");
+                "HIVE", "org.apache.seatunnel.datasource.plugin.hive.HiveDataSourceFactory");
         classLoaderFactoryName.put(
                 "JDBC-ORACLE",
                 "org.apache.seatunnel.datasource.plugin.oracle.jdbc.OracleJdbcDataSourceFactory");
@@ -73,6 +73,9 @@ public class DatasourceLoadConfig {
         classLoaderFactoryName.put(
                 "JDBC-TIDB",
                 "org.apache.seatunnel.datasource.plugin.tidb.jdbc.TidbJdbcDataSourceFactory");
+        classLoaderFactoryName.put(
+                "JDBC-HIVE",
+                "org.apache.seatunnel.datasource.plugin.hive.jdbc.HiveJdbcDataSourceFactory");
         classLoaderFactoryName.put(
                 "KAFKA", "org.apache.seatunnel.datasource.plugin.kafka.KafkaDataSourceFactory");
         classLoaderFactoryName.put(
@@ -97,6 +100,12 @@ public class DatasourceLoadConfig {
         classLoaderFactoryName.put(
                 "JDBC-DB2",
                 "org.apache.seatunnel.datasource.plugin.db2.jdbc.Db2JdbcDataSourceFactory");
+        classLoaderFactoryName.put(
+                "FAKESOURCE",
+                "org.apache.seatunnel.datasource.plugin.fakesource.FakeSourceDataSourceFactory");
+        classLoaderFactoryName.put(
+                "CONSOLE",
+                "org.apache.seatunnel.datasource.plugin.console.ConsoleDataSourceFactory");
 
         classLoaderJarName.put("JDBC-ORACLE", "datasource-jdbc-oracle-");
         classLoaderJarName.put("JDBC-CLICKHOUSE", "datasource-jdbc-clickhouse-");
@@ -118,6 +127,9 @@ public class DatasourceLoadConfig {
         classLoaderJarName.put("JDBC-STARROCKS", "datasource-jdbc-starrocks-");
         classLoaderJarName.put("MONGODB", "datasource-mongodb-");
         classLoaderJarName.put("JDBC-DB2", "datasource-jdbc-db2-");
+        classLoaderJarName.put("JDBC-HIVE", "datasource-jdbc-hive-");
+        classLoaderJarName.put("FAKESOURCE", "datasource-fakesource-");
+        classLoaderJarName.put("CONSOLE", "datasource-console-");
     }
 
     public static final Set<String> pluginSet =
@@ -130,13 +142,16 @@ public class DatasourceLoadConfig {
                     "JDBC-Postgres",
                     "JDBC-SQLServer",
                     "JDBC-TiDB",
+                    "JDBC-Hive",
                     "Kafka",
                     "MySQL-CDC",
                     "S3",
                     "SqlServer-CDC",
                     "StarRocks",
                     "MongoDB",
-                    "JDBC-Db2");
+                    "JDBC-Db2",
+                    "FakeSource",
+                    "Console");
 
     public static Map<String, DatasourceClassLoader> datasourceClassLoaders = new HashMap<>();
 
