@@ -18,7 +18,10 @@
 package org.apache.seatunnel.app.service;
 
 import org.apache.seatunnel.app.common.Result;
+import org.apache.seatunnel.app.domain.dto.job.SeaTunnelJobInstanceDto;
+import org.apache.seatunnel.app.domain.response.executor.JobExecutionStatus;
 import org.apache.seatunnel.app.utils.PageInfo;
+import org.apache.seatunnel.common.constants.JobMode;
 
 public interface ITaskInstanceService<T> {
 
@@ -29,7 +32,13 @@ public interface ITaskInstanceService<T> {
             String stateType,
             String startTime,
             String endTime,
-            String syncTaskType,
+            JobMode jobMode,
             Integer pageNo,
             Integer pageSize);
+
+    Result<JobExecutionStatus> getJobExecutionStatus(Integer userId, long jobInstanceId);
+
+    Result<SeaTunnelJobInstanceDto> getJobExecutionDetail(Integer userId, long jobInstanceId);
+
+    Result<Void> deleteJobInstanceById(Integer userId, long jobInstanceId);
 }
