@@ -16,6 +16,7 @@
  */
 package org.apache.seatunnel.app.service.impl;
 
+import org.apache.seatunnel.shade.com.fasterxml.jackson.core.type.TypeReference;
 import org.apache.seatunnel.shade.com.typesafe.config.ConfigFactory;
 
 import org.apache.seatunnel.app.config.ConnectorDataSourceMapperConfig;
@@ -51,6 +52,7 @@ import org.apache.seatunnel.app.service.IJobInstanceService;
 import org.apache.seatunnel.app.service.IJobTaskService;
 import org.apache.seatunnel.common.constants.PluginType;
 import org.apache.seatunnel.common.utils.ExceptionUtils;
+import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.common.utils.SeaTunnelException;
 import org.apache.seatunnel.datasource.plugin.api.model.TableField;
 import org.apache.seatunnel.server.common.CodeGenerateUtils;
@@ -62,8 +64,6 @@ import org.apache.commons.lang3.StringUtils;
 import org.springframework.stereotype.Service;
 import org.springframework.transaction.annotation.Transactional;
 
-import com.fasterxml.jackson.core.type.TypeReference;
-import com.fasterxml.jackson.databind.ObjectMapper;
 import lombok.extern.slf4j.Slf4j;
 
 import javax.annotation.Resource;
@@ -102,8 +102,6 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
 
     @Resource private ConnectorDataSourceMapperConfig connectorDataSourceMapperConfig;
 
-    private static final ObjectMapper OBJECT_MAPPER = new ObjectMapper();
-
     private void checkConfigIntegrity(JobVersion version, JobTaskInfo jobTaskInfo) {
         if (StringUtils.isEmpty(version.getEnv())) {
             throw new SeatunnelException(
@@ -267,7 +265,7 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
             }
             // check the config can be generated
             jobInstanceService.generateJobConfig(
-                    version.getJobId(), tasks, lines, version.getEnv());
+                    version.getJobId(), tasks, lines, version.getEnv(), null);
             // TODO check schema output and input matched
         } catch (SeaTunnelException e) {
             log.error(ExceptionUtils.getMessage(e));
@@ -314,7 +312,7 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
         Map<String, Object> options = nextConfig.getTransformOptions();
         if (options != null && !options.isEmpty()) {
             Transform transform = Transform.valueOf(nextConfig.getConnectorType().toUpperCase());
-            String transformOptionsStr = OBJECT_MAPPER.writeValueAsString(options);
+            String transformOptionsStr = JsonUtils.toJsonString(options);
 
             List<TransformOption> transformOptions = new ArrayList<>();
 
@@ -406,6 +404,7 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
         funcPermissionCheck(SeatunnelFuncPermissionKeyConstant.SINGLE_TASK_CREATE, 0);
         JobTask jobTask;
         JobTask old = jobTaskDao.getTask(jobVersionId, pluginConfig.getPluginId());
+        String pluginId = pluginConfig.getPluginId();
         try {
             checkConfigFormat(pluginConfig.getConfig());
             long id;
@@ -413,6 +412,10 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
                 id = old.getId();
             } else {
                 id = CodeGenerateUtils.getInstance().genCode();
+                pluginId =
+                        pluginId == null
+                                ? String.valueOf(CodeGenerateUtils.getInstance().genCode())
+                                : pluginId;
             }
             String connectorType;
             String transformOptionsStr = null;
@@ -420,7 +423,7 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
                 connectorType = pluginConfig.getConnectorType();
                 if (pluginConfig.getTransformOptions() != null) {
                     transformOptionsStr =
-                            OBJECT_MAPPER.writeValueAsString(pluginConfig.getTransformOptions());
+                            JsonUtils.toJsonString(pluginConfig.getTransformOptions());
                 }
                 transformOptionCheck(connectorType, transformOptionsStr);
             } else {
@@ -429,7 +432,7 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
             jobTask =
                     JobTask.builder()
                             .id(id)
-                            .pluginId(pluginConfig.getPluginId())
+                            .pluginId(pluginId)
                             .name(pluginConfig.getName())
                             .type(pluginConfig.getType().name().toUpperCase())
                             .dataSourceId(pluginConfig.getDataSourceId())
@@ -443,17 +446,16 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
                             .dataSourceOption(
                                     pluginConfig.getTableOption() == null
                                             ? null
-                                            : OBJECT_MAPPER.writeValueAsString(
-                                                    pluginConfig.getTableOption()))
+                                            : JsonUtils.toJsonString(pluginConfig.getTableOption()))
                             .selectTableFields(
                                     pluginConfig.getSelectTableFields() == null
                                             ? null
-                                            : OBJECT_MAPPER.writeValueAsString(
+                                            : JsonUtils.toJsonString(
                                                     pluginConfig.getSelectTableFields()))
                             .outputSchema(
                                     pluginConfig.getOutputSchema() == null
                                             ? null
-                                            : OBJECT_MAPPER.writeValueAsString(
+                                            : JsonUtils.toJsonString(
                                                     pluginConfig.getOutputSchema()))
                             .transformOptions(transformOptionsStr)
                             .build();
@@ -591,24 +593,24 @@ public class JobTaskServiceImpl extends SeatunnelBaseServiceImpl implements IJob
                     .tableOption(
                             StringUtils.isEmpty(jobTask.getDataSourceOption())
                                     ? null
-                                    : OBJECT_MAPPER.readValue(
+                                    : JsonUtils.parseObject(
                                             jobTask.getDataSourceOption(), DataSourceOption.class))
                     .selectTableFields(
                             StringUtils.isEmpty(jobTask.getSelectTableFields())
                                     ? null
-                                    : OBJECT_MAPPER.readValue(
+                                    : JsonUtils.parseObject(
                                             jobTask.getSelectTableFields(),
                                             SelectTableFields.class))
                     .outputSchema(
                             StringUtils.isEmpty(jobTask.getOutputSchema())
                                     ? null
-                                    : OBJECT_MAPPER.readValue(
+                                    : JsonUtils.parseObject(
                                             jobTask.getOutputSchema(),
                                             new TypeReference<List<DatabaseTableSchemaReq>>() {}))
                     .transformOptions(
                             StringUtils.isEmpty(jobTask.getTransformOptions())
                                     ? null
-                                    : OBJECT_MAPPER.readValue(
+                                    : JsonUtils.parseObject(
                                             jobTask.getTransformOptions(),
                                             new TypeReference<Map<String, Object>>() {}))
                     .config(jobTask.getConfig())
