@@ -18,7 +18,6 @@ package org.apache.seatunnel.app.thirdparty.engine;
 
 import org.apache.seatunnel.shade.com.fasterxml.jackson.core.JsonProcessingException;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.JsonNode;
-import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 
 import org.apache.seatunnel.app.dal.entity.JobInstanceHistory;
 import org.apache.seatunnel.app.dal.entity.JobMetrics;
@@ -26,6 +25,7 @@ import org.apache.seatunnel.app.thirdparty.metrics.IEngineMetricsExtractor;
 import org.apache.seatunnel.common.utils.ExceptionUtils;
 import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.engine.core.job.JobDAGInfo;
+import org.apache.seatunnel.engine.core.job.JobStatus;
 import org.apache.seatunnel.server.common.SeatunnelErrorEnum;
 import org.apache.seatunnel.server.common.SeatunnelException;
 
@@ -50,8 +50,6 @@ import java.util.OptionalDouble;
 public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor {
     @Getter @Setter private SeaTunnelEngineProxy seaTunnelEngineProxy;
 
-    private static final ObjectMapper OBJECT_MAPPER = new ObjectMapper();
-
     public static final String[] clusterHealthMetricsKeys =
             new String[] {
                 "processors",
@@ -92,7 +90,6 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
 
     @Override
     public List<JobMetrics> getMetricsByJobEngineId(@NonNull String jobEngineId) {
-        LinkedHashMap<Integer, JobMetrics> metricsMap = new LinkedHashMap();
 
         LinkedHashMap<Integer, String> jobPipelineStatus = getJobPipelineStatus(jobEngineId);
         try {
@@ -103,83 +100,15 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
 
             JsonNode jsonNode =
                     JsonUtils.stringToJsonNode(seaTunnelEngineProxy.getMetricsContent(jobEngineId));
-            JsonNode sourceReceivedCount = jsonNode.get("SourceReceivedCount");
-            if (sourceReceivedCount != null && sourceReceivedCount.isArray()) {
-                for (JsonNode node : sourceReceivedCount) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setReadRowCount(
-                            currPipelineMetrics.getReadRowCount() + node.get("value").asLong());
-                }
-            }
-
-            JsonNode sinkWriteCount = jsonNode.get("SinkWriteCount");
-            if (sinkWriteCount != null && sinkWriteCount.isArray()) {
-                for (JsonNode node : jsonNode.get("SinkWriteCount")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setWriteRowCount(
-                            currPipelineMetrics.getWriteRowCount() + node.get("value").asLong());
-                }
-            }
-
-            JsonNode sinkWriteQPS = jsonNode.get("SinkWriteQPS");
-            if (sinkWriteQPS != null && sinkWriteQPS.isArray()) {
-                for (JsonNode node : jsonNode.get("SinkWriteQPS")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setWriteQps(
-                            currPipelineMetrics.getWriteQps()
-                                    + (new Double(node.get("value").asDouble())).longValue());
-                }
-            }
-
-            JsonNode sourceReceivedQPS = jsonNode.get("SourceReceivedQPS");
-            if (sourceReceivedQPS != null && sourceReceivedQPS.isArray()) {
-                for (JsonNode node : jsonNode.get("SourceReceivedQPS")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setReadQps(
-                            currPipelineMetrics.getReadQps()
-                                    + (new Double(node.get("value").asDouble())).longValue());
-                }
-            }
-
-            JsonNode cdcRecordEmitDelay = jsonNode.get("CDCRecordEmitDelay");
-            if (cdcRecordEmitDelay != null && cdcRecordEmitDelay.isArray()) {
-                Map<Integer, List<Long>> dataMap = new HashMap<>();
-                for (JsonNode node : jsonNode.get("CDCRecordEmitDelay")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    long value = node.get("value").asLong();
-                    dataMap.computeIfAbsent(pipelineId, n -> new ArrayList<>()).add(value);
-                }
-                dataMap.forEach(
-                        (key, value) -> {
-                            JobMetrics currPipelineMetrics =
-                                    getOrCreatePipelineMetricsMap(
-                                            metricsMap, jobPipelineStatus, key);
-                            OptionalDouble average = value.stream().mapToDouble(a -> a).average();
-                            currPipelineMetrics.setRecordDelay(
-                                    Double.valueOf(average.isPresent() ? average.getAsDouble() : 0)
-                                            .longValue());
-                        });
-            }
+            LinkedHashMap<Integer, JobMetrics> metricsMap =
+                    extractMetrics(jobPipelineStatus, jsonNode);
+            return Arrays.asList(metricsMap.values().toArray(new JobMetrics[0]));
         } catch (JsonProcessingException e) {
             throw new SeatunnelException(
                     SeatunnelErrorEnum.LOAD_ENGINE_METRICS_JSON_ERROR,
                     "SeaTunnel",
                     ExceptionUtils.getMessage(e));
         }
-
-        return Arrays.asList(metricsMap.values().toArray(new JobMetrics[0]));
     }
 
     @Override
@@ -188,6 +117,10 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
         LinkedHashMap<Integer, String> pipelineStatusMap = new LinkedHashMap<>();
         try {
             JsonNode jsonNode = JsonUtils.stringToJsonNode(jobState);
+            if (jsonNode.get("err") != null) {
+                throw new SeatunnelException(
+                        SeatunnelErrorEnum.LOAD_ENGINE_METRICS_ERROR, jsonNode.get("err").asText());
+            }
             Iterator<Map.Entry<String, JsonNode>> iterator =
                     jsonNode.get("pipelineStateMapperMap").fields();
 
@@ -216,31 +149,20 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
     public JobInstanceHistory getJobHistoryById(String jobEngineId) {
         JobDAGInfo jobInfo = seaTunnelEngineProxy.getJobInfo(jobEngineId);
         JobInstanceHistory jobInstanceHistory = new JobInstanceHistory();
-        try {
-            jobInstanceHistory.setDag(OBJECT_MAPPER.writeValueAsString(jobInfo));
-        } catch (JsonProcessingException e) {
-            throw new org.apache.seatunnel.common.utils.SeaTunnelException(e);
-        }
+        jobInstanceHistory.setDag(JsonUtils.toJsonString(jobInfo));
         return jobInstanceHistory;
     }
 
     @Override
     public boolean isJobEnd(@NonNull String jobEngineId) {
-        String jobStatus = seaTunnelEngineProxy.getJobStatus(jobEngineId);
-        return "finished".equalsIgnoreCase(jobStatus)
-                || "canceled".equalsIgnoreCase(jobStatus)
-                || "failed".equalsIgnoreCase(jobStatus);
+        JobStatus jobStatus = seaTunnelEngineProxy.getJobStatus(jobEngineId);
+        return jobStatus == JobStatus.FINISHED
+                || jobStatus == JobStatus.CANCELED
+                || jobStatus == JobStatus.FAILED;
     }
 
     @Override
-    public boolean isJobEndStatus(@NonNull String jobStatus) {
-        return "finished".equalsIgnoreCase(jobStatus)
-                || "canceled".equalsIgnoreCase(jobStatus)
-                || "failed".equalsIgnoreCase(jobStatus);
-    }
-
-    @Override
-    public String getJobStatus(@NonNull String jobEngineId) {
+    public JobStatus getJobStatus(@NonNull String jobEngineId) {
         return seaTunnelEngineProxy.getJobStatus(jobEngineId);
     }
 
@@ -258,7 +180,7 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
             value = value.replace(" ", "");
             Map<String, String> otherMetrics = JsonUtils.toMap(value);
             for (String key : clusterHealthMetricsKeys) {
-                hostMetrics.put(key, otherMetrics.get(key).toString());
+                hostMetrics.put(key, otherMetrics.get(key));
             }
             zetaClusterMetrics.add(hostMetrics);
         }
@@ -267,8 +189,6 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
 
     @Override
     public Map<Integer, JobMetrics> getMetricsByJobEngineIdRTMap(@NonNull String jobEngineId) {
-        LinkedHashMap<Integer, JobMetrics> metricsMap = new LinkedHashMap();
-
         LinkedHashMap<Integer, String> jobPipelineStatus = getJobPipelineStatus(jobEngineId);
         try {
             String metricsContent = seaTunnelEngineProxy.getMetricsContent(jobEngineId);
@@ -276,84 +196,83 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
                 return new HashMap<>();
             }
 
-            JsonNode jsonNode =
-                    JsonUtils.stringToJsonNode(seaTunnelEngineProxy.getMetricsContent(jobEngineId));
-            JsonNode sourceReceivedCount = jsonNode.get("SourceReceivedCount");
-            if (sourceReceivedCount != null && sourceReceivedCount.isArray()) {
-                for (JsonNode node : sourceReceivedCount) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setReadRowCount(
-                            currPipelineMetrics.getReadRowCount() + node.get("value").asLong());
-                }
-            }
-
-            JsonNode sinkWriteCount = jsonNode.get("SinkWriteCount");
-            if (sinkWriteCount != null && sinkWriteCount.isArray()) {
-                for (JsonNode node : jsonNode.get("SinkWriteCount")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setWriteRowCount(
-                            currPipelineMetrics.getWriteRowCount() + node.get("value").asLong());
-                }
-            }
-
-            JsonNode sinkWriteQPS = jsonNode.get("SinkWriteQPS");
-            if (sinkWriteQPS != null && sinkWriteQPS.isArray()) {
-                for (JsonNode node : jsonNode.get("SinkWriteQPS")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setWriteQps(
-                            currPipelineMetrics.getWriteQps()
-                                    + (new Double(node.get("value").asDouble())).longValue());
-                }
-            }
-
-            JsonNode sourceReceivedQPS = jsonNode.get("SourceReceivedQPS");
-            if (sourceReceivedQPS != null && sourceReceivedQPS.isArray()) {
-                for (JsonNode node : jsonNode.get("SourceReceivedQPS")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    JobMetrics currPipelineMetrics =
-                            getOrCreatePipelineMetricsMap(
-                                    metricsMap, jobPipelineStatus, pipelineId);
-                    currPipelineMetrics.setReadQps(
-                            currPipelineMetrics.getReadQps()
-                                    + (new Double(node.get("value").asDouble())).longValue());
-                }
-            }
-
-            JsonNode cdcRecordEmitDelay = jsonNode.get("CDCRecordEmitDelay");
-            if (cdcRecordEmitDelay != null && cdcRecordEmitDelay.isArray()) {
-                Map<Integer, List<Long>> dataMap = new HashMap<>();
-                for (JsonNode node : jsonNode.get("CDCRecordEmitDelay")) {
-                    Integer pipelineId = node.get("tags").get("pipelineId").asInt();
-                    long value = node.get("value").asLong();
-                    dataMap.computeIfAbsent(pipelineId, n -> new ArrayList<>()).add(value);
-                }
-                dataMap.forEach(
-                        (key, value) -> {
-                            JobMetrics currPipelineMetrics =
-                                    getOrCreatePipelineMetricsMap(
-                                            metricsMap, jobPipelineStatus, key);
-                            OptionalDouble average = value.stream().mapToDouble(a -> a).average();
-                            currPipelineMetrics.setRecordDelay(
-                                    Double.valueOf(average.isPresent() ? average.getAsDouble() : 0)
-                                            .longValue());
-                        });
-            }
+            JsonNode jsonNode = JsonUtils.stringToJsonNode(metricsContent);
+            return extractMetrics(jobPipelineStatus, jsonNode);
         } catch (JsonProcessingException e) {
             throw new SeatunnelException(
                     SeatunnelErrorEnum.LOAD_ENGINE_METRICS_JSON_ERROR,
                     "SeaTunnel",
                     ExceptionUtils.getMessage(e));
         }
+    }
 
+    private LinkedHashMap<Integer, JobMetrics> extractMetrics(
+            LinkedHashMap<Integer, String> jobPipelineStatus, JsonNode jsonNode) {
+        LinkedHashMap<Integer, JobMetrics> metricsMap = new LinkedHashMap<>();
+        JsonNode sourceReceivedCount = jsonNode.get("SourceReceivedCount");
+        if (sourceReceivedCount != null && sourceReceivedCount.isArray()) {
+            for (JsonNode node : sourceReceivedCount) {
+                Integer pipelineId = node.get("tags").get("pipelineId").asInt();
+                JobMetrics currPipelineMetrics =
+                        getOrCreatePipelineMetricsMap(metricsMap, jobPipelineStatus, pipelineId);
+                currPipelineMetrics.setReadRowCount(
+                        currPipelineMetrics.getReadRowCount() + node.get("value").asLong());
+            }
+        }
+
+        JsonNode sinkWriteCount = jsonNode.get("SinkWriteCount");
+        if (sinkWriteCount != null && sinkWriteCount.isArray()) {
+            for (JsonNode node : jsonNode.get("SinkWriteCount")) {
+                Integer pipelineId = node.get("tags").get("pipelineId").asInt();
+                JobMetrics currPipelineMetrics =
+                        getOrCreatePipelineMetricsMap(metricsMap, jobPipelineStatus, pipelineId);
+                currPipelineMetrics.setWriteRowCount(
+                        currPipelineMetrics.getWriteRowCount() + node.get("value").asLong());
+            }
+        }
+
+        JsonNode sinkWriteQPS = jsonNode.get("SinkWriteQPS");
+        if (sinkWriteQPS != null && sinkWriteQPS.isArray()) {
+            for (JsonNode node : jsonNode.get("SinkWriteQPS")) {
+                Integer pipelineId = node.get("tags").get("pipelineId").asInt();
+                JobMetrics currPipelineMetrics =
+                        getOrCreatePipelineMetricsMap(metricsMap, jobPipelineStatus, pipelineId);
+                currPipelineMetrics.setWriteQps(
+                        currPipelineMetrics.getWriteQps()
+                                + (new Double(node.get("value").asDouble())).longValue());
+            }
+        }
+
+        JsonNode sourceReceivedQPS = jsonNode.get("SourceReceivedQPS");
+        if (sourceReceivedQPS != null && sourceReceivedQPS.isArray()) {
+            for (JsonNode node : jsonNode.get("SourceReceivedQPS")) {
+                Integer pipelineId = node.get("tags").get("pipelineId").asInt();
+                JobMetrics currPipelineMetrics =
+                        getOrCreatePipelineMetricsMap(metricsMap, jobPipelineStatus, pipelineId);
+                currPipelineMetrics.setReadQps(
+                        currPipelineMetrics.getReadQps()
+                                + (new Double(node.get("value").asDouble())).longValue());
+            }
+        }
+
+        JsonNode cdcRecordEmitDelay = jsonNode.get("CDCRecordEmitDelay");
+        if (cdcRecordEmitDelay != null && cdcRecordEmitDelay.isArray()) {
+            Map<Integer, List<Long>> dataMap = new HashMap<>();
+            for (JsonNode node : jsonNode.get("CDCRecordEmitDelay")) {
+                Integer pipelineId = node.get("tags").get("pipelineId").asInt();
+                long value = node.get("value").asLong();
+                dataMap.computeIfAbsent(pipelineId, n -> new ArrayList<>()).add(value);
+            }
+            dataMap.forEach(
+                    (key, value) -> {
+                        JobMetrics currPipelineMetrics =
+                                getOrCreatePipelineMetricsMap(metricsMap, jobPipelineStatus, key);
+                        OptionalDouble average = value.stream().mapToDouble(a -> a).average();
+                        currPipelineMetrics.setRecordDelay(
+                                Double.valueOf(average.isPresent() ? average.getAsDouble() : 0)
+                                        .longValue());
+                    });
+        }
         return metricsMap;
     }
 
@@ -368,13 +287,11 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
                 return new HashMap<>();
             }
             JsonNode jsonNode = JsonUtils.stringToJsonNode(allJobMetricsContent);
-            Iterator<JsonNode> iterator = jsonNode.iterator();
-            while (iterator.hasNext()) {
-                LinkedHashMap<Integer, JobMetrics> metricsMap = new LinkedHashMap();
-                JsonNode next = iterator.next();
+            for (JsonNode item : jsonNode) {
+                LinkedHashMap<Integer, JobMetrics> metricsMap = new LinkedHashMap<>();
 
-                JsonNode sourceReceivedCount = next.get("metrics").get("SourceReceivedCount");
-                Long jobEngineId = 0L;
+                JsonNode sourceReceivedCount = item.get("metrics").get("SourceReceivedCount");
+                long jobEngineId = 0L;
                 if (sourceReceivedCount != null && sourceReceivedCount.isArray()) {
                     for (JsonNode node : sourceReceivedCount) {
                         jobEngineId = node.get("tags").get("jobId").asLong();
@@ -386,7 +303,7 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
                     }
                 }
 
-                JsonNode sinkWriteCount = next.get("metrics").get("SinkWriteCount");
+                JsonNode sinkWriteCount = item.get("metrics").get("SinkWriteCount");
                 if (sinkWriteCount != null && sinkWriteCount.isArray()) {
                     for (JsonNode node : sinkWriteCount) {
                         jobEngineId = node.get("tags").get("jobId").asLong();
@@ -399,7 +316,7 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
                     }
                 }
 
-                JsonNode sinkWriteQPS = next.get("metrics").get("SinkWriteQPS");
+                JsonNode sinkWriteQPS = item.get("metrics").get("SinkWriteQPS");
                 if (sinkWriteQPS != null && sinkWriteQPS.isArray()) {
                     for (JsonNode node : sinkWriteQPS) {
                         Integer pipelineId = node.get("tags").get("pipelineId").asInt();
@@ -411,7 +328,7 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
                     }
                 }
 
-                JsonNode sourceReceivedQPS = next.get("metrics").get("SourceReceivedQPS");
+                JsonNode sourceReceivedQPS = item.get("metrics").get("SourceReceivedQPS");
                 if (sourceReceivedQPS != null && sourceReceivedQPS.isArray()) {
                     for (JsonNode node : sourceReceivedQPS) {
                         Integer pipelineId = node.get("tags").get("pipelineId").asInt();
@@ -423,7 +340,7 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
                     }
                 }
 
-                JsonNode cdcRecordEmitDelay = next.get("metrics").get("CDCRecordEmitDelay");
+                JsonNode cdcRecordEmitDelay = item.get("metrics").get("CDCRecordEmitDelay");
                 if (cdcRecordEmitDelay != null && cdcRecordEmitDelay.isArray()) {
                     Map<Integer, List<Long>> dataMap = new HashMap<>();
                     for (JsonNode node : cdcRecordEmitDelay) {
@@ -452,7 +369,7 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
             }
 
         } catch (Exception e) {
-            e.printStackTrace();
+            log.error("Failed to fetch running job metrics", e);
         }
         return allRunningJobMetricsHashMap;
     }
@@ -462,7 +379,7 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
         JobMetrics currPipelineMetrics = metricsMap.get(pipelineId);
         if (currPipelineMetrics == null) {
             currPipelineMetrics = new JobMetrics();
-            currPipelineMetrics.setStatus("RUNNING");
+            currPipelineMetrics.setStatus(JobStatus.RUNNING);
             currPipelineMetrics.setPipelineId(pipelineId);
             metricsMap.put(pipelineId, currPipelineMetrics);
         }
@@ -477,7 +394,10 @@ public class SeaTunnelEngineMetricsExtractor implements IEngineMetricsExtractor
         if (currPipelineMetrics == null) {
             currPipelineMetrics = new JobMetrics();
             metricsMap.put(pipelineId, currPipelineMetrics);
-            currPipelineMetrics.setStatus(jobPipelineStatus.get(pipelineId));
+            currPipelineMetrics.setStatus(
+                    "DEPLOYING".equals(jobPipelineStatus.get(pipelineId))
+                            ? JobStatus.SCHEDULED
+                            : JobStatus.valueOf(jobPipelineStatus.get(pipelineId)));
             currPipelineMetrics.setPipelineId(pipelineId);
         }
         return currPipelineMetrics;
