@@ -19,13 +19,15 @@ import i18n from '@/locales'
 const { t } = i18n.global
 export const getRemainTime = (remain: number): any => {
     if(!remain) return 
+    let d = parseInt(remain / 60 / 60 / 24 + '')
     let h = parseInt(remain / 60 / 60 % 24 + '')
     let m = parseInt(remain / 60 % 60 + '')
     let s = parseInt(remain % 60 + '')
+    const dText = d > 0 ? `${d}${t('common.day')}` : ''
     const hText = h > 0 ? `${h}${t('common.hour')}` : ''
     const mText = m > 0 ? `${m}${t('common.min')}` : ''
     const sText = s > 0 ? `${s}${t('common.second')}` : ''
-    return hText + mText + sText
+    return dText + hText + mText + sText
     
 }
 
